#!/bin/bash

set -o nounset -o errexit -o pipefail -o errtrace

error() {
   local sourcefile=$1
   local lineno=$2
   echo "ERROR at ${sourcefile}:${lineno}; Last logs:"
   grep otto /var/log/syslog | tail -n 20
}
trap 'error "${BASH_SOURCE}" "${LINENO}"' ERR

oe() { "$@" 2>&1 | logger -t otto > /dev/null; }
ol() { echo "[otto] $@"; }

# cloud-config can interfere with apt commands if it's still in progress
ol "Waiting for cloud-config to complete..."
until [[ -f /var/lib/cloud/instance/boot-finished ]]; do
  sleep 0.5
done

ol "Adding apt repositories and updating..."
export DEBIAN_FRONTEND=noninteractive
oe sudo apt-get update -y
oe sudo apt-get install -y software-properties-common
oe sudo add-apt-repository -y ppa:ondrej/php5-5.6
# Seems to be required to prevent "unauthenticated packages"
# errors out of apt-get install.
oe sudo apt-key update
oe sudo apt-get update -y

ol "Installing PHP VCSs, Apache, and other packages..."
oe sudo apt-get install -y apache2 php5 libapache2-mod-php5 \
  bzr git mercurial build-essential \
  curl \
  php5-mcrypt php5-mysql php5-fpm php5-gd php5-readline php5-pgsql

ol "Extracting app..."
sudo mkdir -p /srv/otto-app
sudo tar zxf /tmp/otto-app.tgz -C /srv/otto-app

ol "Setting permissions..."
oe sudo chown -R www-data: /srv/otto-app

if [ -f /srv/otto-app/composer.json ]; then
  ol "Installing Composer..."
  cd /tmp
  curl -sS https://getcomposer.org/installer | php
  oe sudo mv composer.phar /usr/local/bin/composer

  ol "Running composer install..."
  oe sudo -u www-data /usr/local/bin/composer install --working-dir /srv/otto-app --no-dev --no-interaction
fi


ol "Configuring apache..."
oe sudo rm /etc/apache2/sites-enabled/000-default.conf

cat <<APACHECONF | sudo tee /etc/apache2/sites-enabled/otto-app.conf > /dev/null
# Generated by Otto
<VirtualHost *:80>
  DocumentRoot /srv/otto-app

  <Directory /srv/otto-app/>
    Require all granted
  </Directory>
</VirtualHost>
APACHECONF


ol "...done!"
